==> haskell-aws-0.20-98-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-aws.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: aws
version: 0.20
id: aws-0.20-Icg26Cgzq6wUyr8wdz3nl
key: aws-0.20-Icg26Cgzq6wUyr8wdz3nl
license: BSD-3-Clause
copyright: See contributors list in README and LICENSE file
maintainer: aristidb@gmail.com
author: Aristid Breitkreuz, contributors see README
homepage: http://github.com/aristidb/aws
synopsis: Amazon Web Services (AWS) for Haskell
description:
    Bindings for Amazon Web Services (AWS), with the aim of supporting all AWS services. To see a high level overview of the library, see the README at <https://github.com/aristidb/aws/blob/master/README.md>.
category: Network, Web, AWS, Cloud, Distributed Computing
abi: ec6b552d38497066116a4fc6b2edfd2b
exposed: True
exposed-modules:
    Aws Aws.Aws Aws.Core Aws.DynamoDb Aws.DynamoDb.Commands
    Aws.DynamoDb.Commands.BatchGetItem
    Aws.DynamoDb.Commands.BatchWriteItem
    Aws.DynamoDb.Commands.DeleteItem Aws.DynamoDb.Commands.GetItem
    Aws.DynamoDb.Commands.PutItem Aws.DynamoDb.Commands.Query
    Aws.DynamoDb.Commands.Scan Aws.DynamoDb.Commands.Table
    Aws.DynamoDb.Commands.UpdateItem Aws.DynamoDb.Core
    Aws.Ec2.InstanceMetadata Aws.Iam Aws.Iam.Commands
    Aws.Iam.Commands.CreateAccessKey Aws.Iam.Commands.CreateUser
    Aws.Iam.Commands.DeleteAccessKey Aws.Iam.Commands.DeleteUser
    Aws.Iam.Commands.DeleteUserPolicy Aws.Iam.Commands.GetUser
    Aws.Iam.Commands.GetUserPolicy Aws.Iam.Commands.ListAccessKeys
    Aws.Iam.Commands.ListMfaDevices Aws.Iam.Commands.ListUserPolicies
    Aws.Iam.Commands.ListUsers Aws.Iam.Commands.PutUserPolicy
    Aws.Iam.Commands.UpdateAccessKey Aws.Iam.Commands.UpdateUser
    Aws.Iam.Core Aws.Iam.Internal Aws.Network Aws.S3 Aws.S3.Commands
    Aws.S3.Commands.CopyObject Aws.S3.Commands.DeleteBucket
    Aws.S3.Commands.DeleteObject Aws.S3.Commands.DeleteObjectVersion
    Aws.S3.Commands.DeleteObjects Aws.S3.Commands.GetBucket
    Aws.S3.Commands.GetBucketLocation
    Aws.S3.Commands.GetBucketObjectVersions Aws.S3.Commands.GetObject
    Aws.S3.Commands.GetService Aws.S3.Commands.HeadObject
    Aws.S3.Commands.Multipart Aws.S3.Commands.PutBucket
    Aws.S3.Commands.PutObject Aws.S3.Core Aws.Ses Aws.Ses.Commands
    Aws.Ses.Commands.DeleteIdentity
    Aws.Ses.Commands.GetIdentityDkimAttributes
    Aws.Ses.Commands.GetIdentityNotificationAttributes
    Aws.Ses.Commands.GetIdentityVerificationAttributes
    Aws.Ses.Commands.ListIdentities Aws.Ses.Commands.SendRawEmail
    Aws.Ses.Commands.SetIdentityDkimEnabled
    Aws.Ses.Commands.SetIdentityFeedbackForwardingEnabled
    Aws.Ses.Commands.SetIdentityNotificationTopic
    Aws.Ses.Commands.VerifyDomainDkim
    Aws.Ses.Commands.VerifyDomainIdentity
    Aws.Ses.Commands.VerifyEmailIdentity Aws.Ses.Core Aws.SimpleDb
    Aws.SimpleDb.Commands Aws.SimpleDb.Commands.Attributes
    Aws.SimpleDb.Commands.Domain Aws.SimpleDb.Commands.Select
    Aws.SimpleDb.Core Aws.Sqs Aws.Sqs.Commands Aws.Sqs.Commands.Message
    Aws.Sqs.Commands.Permission Aws.Sqs.Commands.Queue
    Aws.Sqs.Commands.QueueAttributes Aws.Sqs.Core
import-dirs: /usr/lib/ghc-8.4.3/site-local/aws-0.20
library-dirs: /usr/lib/ghc-8.4.3/site-local/aws-0.20
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.4.3/aws-0.20
hs-libraries: HSaws-0.20-Icg26Cgzq6wUyr8wdz3nl
depends:
    aeson-1.4.1.0-Je86IRhAZ9i9fcEQGpo4BI
    attoparsec-0.13.2.2-KZXutHSJyFFFErNezqs0Rb base-4.11.1.0
    base16-bytestring-0.1.1.6-I0igvRcEwRNBMqqPC2yQBh
    base64-bytestring-1.0.0.1-4OCIe2BZn8jKI191JIXI37
    blaze-builder-0.4.1.0-Gz7BwSYlOrTDOutVN7e028
    byteable-0.1.1-APABKKN6nDlC3QxQBw4YlY bytestring-0.10.8.2
    case-insensitive-1.2.0.11-GjimmYhRn324HWbQThQUra
    cereal-0.5.7.0-GeNBgd8Wa452X4EoKnwsnC
    conduit-1.3.0.3-2pJCSncQS97DBjtJl8NaxW
    conduit-extra-1.3.0-864ookHJk7rCpN6TNZfIxg containers-0.5.11.0
    cryptonite-0.25-FGChimResic4ujDRfnuPjv
    data-default-0.7.1.1-ANph70WEdAe9A1H2IGNxHn directory-1.3.1.5
    filepath-1.4.2 http-conduit-2.3.2-6O2kutLmqn7KH8SYgO4XAq
    http-types-0.12.2-Hp3f62sblzVJDS3ORILSVQ
    lifted-base-0.2.3.12-4NQhoAXDZga8XElWqeIe2X
    memory-0.14.18-9akydHRk1ZP1zabNg9e0SJ
    monad-control-1.0.2.3-LF1NHBZIRgG6fG7d7ZwfSq
    exceptions-0.10.0-IRO0p79DXGKGDsbbDc50a8 mtl-2.2.2
    network-2.7.0.2-DyiwBfTiS6W3HYGx1tN94w
    old-locale-1.0.0.7-26K7wLFR2jK44UeOklvTCh
    resourcet-1.2.1-HIT1uiDVpcxDTEPc4WOeAH
    safe-0.3.17-HEmZRpXGD3s2ywM3rHJ1ur
    scientific-0.3.6.2-IBbwozwBAuO8Adqyj8FlXl
    tagged-0.8.6-8akQ1aZG2N2GFJpoB5eGXO text-1.2.3.0 time-1.8.0.2
    transformers-0.5.5.0
    unordered-containers-0.2.9.0-EtLPGprUM82GTPrcqDz1YE
    utf8-string-1.0.1.1-LRSjvSC6FZkKPp48Qszoj8
    vector-0.12.0.1-1fezwShzdEfG3Hp1Pmvjkq
    xml-conduit-1.8.0.1-mKZKrVhoNQGZXyAz63TBo
abi-depends: aeson-1.4.1.0-Je86IRhAZ9i9fcEQGpo4BI=e763a4a7c222101a91911389c36d4497
             attoparsec-0.13.2.2-KZXutHSJyFFFErNezqs0Rb=00fe5c2fcfc4c1dbb030be8823e7ce5f
             base-4.11.1.0=9da3f387598d41928f3ebf8097acf9b3
             base16-bytestring-0.1.1.6-I0igvRcEwRNBMqqPC2yQBh=0cc0842c69ffec2c0f1c4a27d1f518e1
             base64-bytestring-1.0.0.1-4OCIe2BZn8jKI191JIXI37=6373b2ec1ae2585bcca6cddbee5d3e75
             blaze-builder-0.4.1.0-Gz7BwSYlOrTDOutVN7e028=84ea2e9d87e56b4ceb814f92752c9208
             byteable-0.1.1-APABKKN6nDlC3QxQBw4YlY=1b344c82815219929c6d7eafd49ac50e
             bytestring-0.10.8.2=76943c00398d547fb172e56c2f93c635
             case-insensitive-1.2.0.11-GjimmYhRn324HWbQThQUra=bcd8ba72b672d042505b8fc55f637c88
             cereal-0.5.7.0-GeNBgd8Wa452X4EoKnwsnC=91a5befe140ca1e57734aef5b9be7102
             conduit-1.3.0.3-2pJCSncQS97DBjtJl8NaxW=a0efd684e93e35619771d8ef5ca6ca30
             conduit-extra-1.3.0-864ookHJk7rCpN6TNZfIxg=ddbf96969c9f43f5217fe3fb85700b26
             containers-0.5.11.0=7795138514357bd2e41eaf59b6cfce4f
             cryptonite-0.25-FGChimResic4ujDRfnuPjv=29137cb7d1f614608fd8f81085dbaf61
             data-default-0.7.1.1-ANph70WEdAe9A1H2IGNxHn=0b9cf97a5dc28f689e30b5244977846e
             directory-1.3.1.5=e563da47c8e71ee27761a9b9d172f1ec
             filepath-1.4.2=f8b35940dbf3bb5331e1c5ab9738687d
             http-conduit-2.3.2-6O2kutLmqn7KH8SYgO4XAq=d4270f89887bd53e647278f98060be70
             http-types-0.12.2-Hp3f62sblzVJDS3ORILSVQ=0e3f56446088d76b8499612b29457455
             lifted-base-0.2.3.12-4NQhoAXDZga8XElWqeIe2X=58b9a8c6dad79fba996860c72139fcdb
             memory-0.14.18-9akydHRk1ZP1zabNg9e0SJ=a6560a06cd4458200b1075ace7506fc2
             monad-control-1.0.2.3-LF1NHBZIRgG6fG7d7ZwfSq=a47d843a3db6efd069d92470c607da07
             exceptions-0.10.0-IRO0p79DXGKGDsbbDc50a8=e9779fb859fee3584d68df46d12eac41
             mtl-2.2.2=3cf3b316ad8e985e039ee3b498a98253
             network-2.7.0.2-DyiwBfTiS6W3HYGx1tN94w=49278efe672b4f4a36004f8349b262f7
             old-locale-1.0.0.7-26K7wLFR2jK44UeOklvTCh=624bb9fc159afd36b39208b6844f8edd
             resourcet-1.2.1-HIT1uiDVpcxDTEPc4WOeAH=63beb88722f12bd2df4fa896ef9b7f12
             safe-0.3.17-HEmZRpXGD3s2ywM3rHJ1ur=f24d7708a3245ecd805ff7d598d8872c
             scientific-0.3.6.2-IBbwozwBAuO8Adqyj8FlXl=a9e5116cfd8f4e8564ae54d9515a25b1
             tagged-0.8.6-8akQ1aZG2N2GFJpoB5eGXO=4bf567357cce5e796341c1faefad6985
             text-1.2.3.0=be4c3e1c57cff1d501eb0e876706a48d
             time-1.8.0.2=976962cc6498b843f1efb5bef740838e
             transformers-0.5.5.0=633c3e5ec737c360775b452ce9aa1e0b
             unordered-containers-0.2.9.0-EtLPGprUM82GTPrcqDz1YE=d999168fa5a35d048ce4f3e0442b4ae6
             utf8-string-1.0.1.1-LRSjvSC6FZkKPp48Qszoj8=2191a818a7f61b012f58bd96949826c6
             vector-0.12.0.1-1fezwShzdEfG3Hp1Pmvjkq=2d4c17574909e037fa0256847c747647
             xml-conduit-1.8.0.1-mKZKrVhoNQGZXyAz63TBo=9629e91b300dd75cf830c3d8f7ea3cb3
haddock-interfaces: /usr/share/doc/haskell-aws/html/aws.haddock
haddock-html: /usr/share/doc/haskell-aws/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-aws-0.20-102-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-aws.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: aws
version: 0.20
id: aws-0.20-LbPMk0gqv7xH7sIBLwajnk
key: aws-0.20-LbPMk0gqv7xH7sIBLwajnk
license: BSD-3-Clause
copyright: See contributors list in README and LICENSE file
maintainer: aristidb@gmail.com
author: Aristid Breitkreuz, contributors see README
homepage: http://github.com/aristidb/aws
synopsis: Amazon Web Services (AWS) for Haskell
description:
    Bindings for Amazon Web Services (AWS), with the aim of supporting all AWS services. To see a high level overview of the library, see the README at <https://github.com/aristidb/aws/blob/master/README.md>.
category: Network, Web, AWS, Cloud, Distributed Computing
abi: 5484dfe1af823a61cedabf8d264edd66
exposed: True
exposed-modules:
    Aws Aws.Aws Aws.Core Aws.DynamoDb Aws.DynamoDb.Commands
    Aws.DynamoDb.Commands.BatchGetItem
    Aws.DynamoDb.Commands.BatchWriteItem
    Aws.DynamoDb.Commands.DeleteItem Aws.DynamoDb.Commands.GetItem
    Aws.DynamoDb.Commands.PutItem Aws.DynamoDb.Commands.Query
    Aws.DynamoDb.Commands.Scan Aws.DynamoDb.Commands.Table
    Aws.DynamoDb.Commands.UpdateItem Aws.DynamoDb.Core
    Aws.Ec2.InstanceMetadata Aws.Iam Aws.Iam.Commands
    Aws.Iam.Commands.CreateAccessKey Aws.Iam.Commands.CreateUser
    Aws.Iam.Commands.DeleteAccessKey Aws.Iam.Commands.DeleteUser
    Aws.Iam.Commands.DeleteUserPolicy Aws.Iam.Commands.GetUser
    Aws.Iam.Commands.GetUserPolicy Aws.Iam.Commands.ListAccessKeys
    Aws.Iam.Commands.ListMfaDevices Aws.Iam.Commands.ListUserPolicies
    Aws.Iam.Commands.ListUsers Aws.Iam.Commands.PutUserPolicy
    Aws.Iam.Commands.UpdateAccessKey Aws.Iam.Commands.UpdateUser
    Aws.Iam.Core Aws.Iam.Internal Aws.Network Aws.S3 Aws.S3.Commands
    Aws.S3.Commands.CopyObject Aws.S3.Commands.DeleteBucket
    Aws.S3.Commands.DeleteObject Aws.S3.Commands.DeleteObjectVersion
    Aws.S3.Commands.DeleteObjects Aws.S3.Commands.GetBucket
    Aws.S3.Commands.GetBucketLocation
    Aws.S3.Commands.GetBucketObjectVersions Aws.S3.Commands.GetObject
    Aws.S3.Commands.GetService Aws.S3.Commands.HeadObject
    Aws.S3.Commands.Multipart Aws.S3.Commands.PutBucket
    Aws.S3.Commands.PutObject Aws.S3.Core Aws.Ses Aws.Ses.Commands
    Aws.Ses.Commands.DeleteIdentity
    Aws.Ses.Commands.GetIdentityDkimAttributes
    Aws.Ses.Commands.GetIdentityNotificationAttributes
    Aws.Ses.Commands.GetIdentityVerificationAttributes
    Aws.Ses.Commands.ListIdentities Aws.Ses.Commands.SendRawEmail
    Aws.Ses.Commands.SetIdentityDkimEnabled
    Aws.Ses.Commands.SetIdentityFeedbackForwardingEnabled
    Aws.Ses.Commands.SetIdentityNotificationTopic
    Aws.Ses.Commands.VerifyDomainDkim
    Aws.Ses.Commands.VerifyDomainIdentity
    Aws.Ses.Commands.VerifyEmailIdentity Aws.Ses.Core Aws.SimpleDb
    Aws.SimpleDb.Commands Aws.SimpleDb.Commands.Attributes
    Aws.SimpleDb.Commands.Domain Aws.SimpleDb.Commands.Select
    Aws.SimpleDb.Core Aws.Sqs Aws.Sqs.Commands Aws.Sqs.Commands.Message
    Aws.Sqs.Commands.Permission Aws.Sqs.Commands.Queue
    Aws.Sqs.Commands.QueueAttributes Aws.Sqs.Core
import-dirs: /usr/lib/ghc-8.4.3/site-local/aws-0.20
library-dirs: /usr/lib/ghc-8.4.3/site-local/aws-0.20
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.4.3/aws-0.20
hs-libraries: HSaws-0.20-LbPMk0gqv7xH7sIBLwajnk
depends:
    aeson-1.4.1.0-DC05NYridW9CuV0L6TLprZ
    attoparsec-0.13.2.2-LRNbjQIitwn4Jmo3hCxwCI base-4.11.1.0
    base16-bytestring-0.1.1.6-I0igvRcEwRNBMqqPC2yQBh
    base64-bytestring-1.0.0.1-4OCIe2BZn8jKI191JIXI37
    blaze-builder-0.4.1.0-Gz7BwSYlOrTDOutVN7e028
    byteable-0.1.1-APABKKN6nDlC3QxQBw4YlY bytestring-0.10.8.2
    case-insensitive-1.2.0.11-GjimmYhRn324HWbQThQUra
    cereal-0.5.7.0-GeNBgd8Wa452X4EoKnwsnC
    conduit-1.3.1-JR2jMm57F9p4PvlZ0CCgmp
    conduit-extra-1.3.0-1ceQCG5GhpiGMqgNrteXTC containers-0.5.11.0
    cryptonite-0.25-FGChimResic4ujDRfnuPjv
    data-default-0.7.1.1-ANph70WEdAe9A1H2IGNxHn directory-1.3.1.5
    filepath-1.4.2 http-conduit-2.3.2-CpCt9TYnsQqHyoOerXJFSi
    http-types-0.12.2-A3iO9yi4jtVBISyGmGh0IQ
    lifted-base-0.2.3.12-HMOl5nUqd7vEyGkiEGhayt
    memory-0.14.18-9akydHRk1ZP1zabNg9e0SJ
    monad-control-1.0.2.3-BHiQ1sXZtC2F5CXPOd3haE
    exceptions-0.10.0-IRO0p79DXGKGDsbbDc50a8 mtl-2.2.2
    network-2.7.0.2-DHEaxB3Qzor483iLxewsye
    old-locale-1.0.0.7-26K7wLFR2jK44UeOklvTCh
    resourcet-1.2.2-4JidlQy3pgh1sp3zp97uMg
    safe-0.3.17-HEmZRpXGD3s2ywM3rHJ1ur
    scientific-0.3.6.2-IBbwozwBAuO8Adqyj8FlXl
    tagged-0.8.6-8akQ1aZG2N2GFJpoB5eGXO text-1.2.3.0 time-1.8.0.2
    transformers-0.5.5.0
    unordered-containers-0.2.9.0-EtLPGprUM82GTPrcqDz1YE
    utf8-string-1.0.1.1-LRSjvSC6FZkKPp48Qszoj8
    vector-0.12.0.1-1fezwShzdEfG3Hp1Pmvjkq
    xml-conduit-1.8.0.1-8rz5v5OVC4L8Hwj1q5TDge
abi-depends: aeson-1.4.1.0-DC05NYridW9CuV0L6TLprZ=2dabf93ee02d5485cbe316a08ea94024
             attoparsec-0.13.2.2-LRNbjQIitwn4Jmo3hCxwCI=4a615f6f9c3fdb3bc12ed255f597d820
             base-4.11.1.0=9da3f387598d41928f3ebf8097acf9b3
             base16-bytestring-0.1.1.6-I0igvRcEwRNBMqqPC2yQBh=0cc0842c69ffec2c0f1c4a27d1f518e1
             base64-bytestring-1.0.0.1-4OCIe2BZn8jKI191JIXI37=6373b2ec1ae2585bcca6cddbee5d3e75
             blaze-builder-0.4.1.0-Gz7BwSYlOrTDOutVN7e028=84ea2e9d87e56b4ceb814f92752c9208
             byteable-0.1.1-APABKKN6nDlC3QxQBw4YlY=1b344c82815219929c6d7eafd49ac50e
             bytestring-0.10.8.2=76943c00398d547fb172e56c2f93c635
             case-insensitive-1.2.0.11-GjimmYhRn324HWbQThQUra=bcd8ba72b672d042505b8fc55f637c88
             cereal-0.5.7.0-GeNBgd8Wa452X4EoKnwsnC=91a5befe140ca1e57734aef5b9be7102
             conduit-1.3.1-JR2jMm57F9p4PvlZ0CCgmp=16734a62a84599c1bebef0162694b893
             conduit-extra-1.3.0-1ceQCG5GhpiGMqgNrteXTC=230128ec55e38b00393d33cbdc0833cf
             containers-0.5.11.0=7795138514357bd2e41eaf59b6cfce4f
             cryptonite-0.25-FGChimResic4ujDRfnuPjv=29137cb7d1f614608fd8f81085dbaf61
             data-default-0.7.1.1-ANph70WEdAe9A1H2IGNxHn=0b9cf97a5dc28f689e30b5244977846e
             directory-1.3.1.5=e563da47c8e71ee27761a9b9d172f1ec
             filepath-1.4.2=f8b35940dbf3bb5331e1c5ab9738687d
             http-conduit-2.3.2-CpCt9TYnsQqHyoOerXJFSi=b0587dc8852b44bb51069974b4fae982
             http-types-0.12.2-A3iO9yi4jtVBISyGmGh0IQ=0dc8a0f99295ecdb31f6b687393563ad
             lifted-base-0.2.3.12-HMOl5nUqd7vEyGkiEGhayt=d5ae419deaf1808df9edd880e997888f
             memory-0.14.18-9akydHRk1ZP1zabNg9e0SJ=a6560a06cd4458200b1075ace7506fc2
             monad-control-1.0.2.3-BHiQ1sXZtC2F5CXPOd3haE=4ee72eedcbb414f057fc28d296f7ff55
             exceptions-0.10.0-IRO0p79DXGKGDsbbDc50a8=e9779fb859fee3584d68df46d12eac41
             mtl-2.2.2=3cf3b316ad8e985e039ee3b498a98253
             network-2.7.0.2-DHEaxB3Qzor483iLxewsye=6aeecf5609d81737c1dbc231763db621
             old-locale-1.0.0.7-26K7wLFR2jK44UeOklvTCh=624bb9fc159afd36b39208b6844f8edd
             resourcet-1.2.2-4JidlQy3pgh1sp3zp97uMg=4d4f7e54bda4225324828951165b6e2b
             safe-0.3.17-HEmZRpXGD3s2ywM3rHJ1ur=f24d7708a3245ecd805ff7d598d8872c
             scientific-0.3.6.2-IBbwozwBAuO8Adqyj8FlXl=a9e5116cfd8f4e8564ae54d9515a25b1
             tagged-0.8.6-8akQ1aZG2N2GFJpoB5eGXO=4bf567357cce5e796341c1faefad6985
             text-1.2.3.0=be4c3e1c57cff1d501eb0e876706a48d
             time-1.8.0.2=976962cc6498b843f1efb5bef740838e
             transformers-0.5.5.0=633c3e5ec737c360775b452ce9aa1e0b
             unordered-containers-0.2.9.0-EtLPGprUM82GTPrcqDz1YE=d999168fa5a35d048ce4f3e0442b4ae6
             utf8-string-1.0.1.1-LRSjvSC6FZkKPp48Qszoj8=2191a818a7f61b012f58bd96949826c6
             vector-0.12.0.1-1fezwShzdEfG3Hp1Pmvjkq=2d4c17574909e037fa0256847c747647
             xml-conduit-1.8.0.1-8rz5v5OVC4L8Hwj1q5TDge=ba8869dc23d90194f848cd351c9e175a
haddock-interfaces: /usr/share/doc/haskell-aws/html/aws.haddock
haddock-html: /usr/share/doc/haskell-aws/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
